@@ -1,4 +1,5 @@
 #!/usr/bin/perl
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 use warnings;
 use strict;
@@ -15,7 +16,8 @@ while (<>) {
 	$b =~ s/^W(?:EB)?\s+/\\x01/;
 	$b =~ s/^VERISIGN\s+/\\x04" "/;
 	$b = "\\x03" if $b eq 'NONE';
-	$b = "\\x08whois.afilias-grs.info" if $b eq 'AFILIAS';
+	$b =~ s/^RECURSIVE\s+/\\x08" "/;
+	$b = "\\x08$b" if $b eq 'whois.flexireg.net';
 	$b = "\\x08$b" if $b eq 'whois.registry.in';
 	$b = "\\x0C" if $b eq 'ARPA';
 	$b = "\\x0D" if $b eq 'IP6';
