@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2022 Marco d'Itri <md@linux.it>.
+ * Copyright (C) Marco d'Itri <md@linux.it>.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -347,7 +347,7 @@ int handle_query(const char *hserver, const char *hport,
 	    sockfd = openconn(server + 1, NULL);
 	    free(server);
 	    server = query_crsnic(sockfd, query);
-	    if (no_recursion)
+	    if (no_recursion && server)
 		server[0] = '\0';
 	    break;
 	case 8:
@@ -356,7 +356,7 @@ int handle_query(const char *hserver, const char *hport,
 	    sockfd = openconn(server + 1, NULL);
 	    free(server);
 	    server = query_afilias(sockfd, query);
-	    if (no_recursion)
+	    if (no_recursion && server)
 		server[0] = '\0';
 	    break;
 	case 0x0A:
@@ -409,7 +409,7 @@ int handle_query(const char *hserver, const char *hport,
     }
 
     sockfd = openconn(server, port);
-
+    free(server);
     server = do_query(sockfd, query_string);
     free(query_string);
 
@@ -638,15 +638,9 @@ const char *whereas(const unsigned long asn)
 {
     int i;
 
-    if (asn > 65535) {
-	for (i = 0; as32_assign[i].serv; i++)
-	    if (asn >= as32_assign[i].first && asn <= as32_assign[i].last)
-		return as32_assign[i].serv;
-    } else {
-	for (i = 0; as_assign[i].serv; i++)
-	    if (asn >= as_assign[i].first && asn <= as_assign[i].last)
-		return as_assign[i].serv;
-    }
+    for (i = 0; as_assign[i].serv; i++)
+	if (asn >= as_assign[i].first && asn <= as_assign[i].last)
+	    return as_assign[i].serv;
     return "\x06";
 }
 
@@ -1151,7 +1145,7 @@ int connect_with_timeout(int fd, const struct sockaddr *addr,
     return 0;
 }
 
-void NORETURN alarm_handler(int signum)
+void NORETURN alarm_handler(UNUSED int signum)
 {
     close(sockfd);
     err_quit(_("Timeout."));
@@ -1509,7 +1503,7 @@ int isasciidigit(const char c)
     return (c >= '0' && c <= '9') ? 1 : 0;
 }
 
-/* http://www.ripe.net/ripe/docs/databaseref-manual.html */
+/* https://www.ripe.net/ripe/docs/databaseref-manual.html */
 
 void NORETURN usage(int error)
 {
